///	MaximiseButton.cpp - Button to maximise the window.
///	--------------------------------------------------------------------------
///	This file is part of 'Niall's Pedal Board', a simple ASIO VST host.
///	Copyright (C) 2005  Niall Moody
///	
///	This program is free software; you can redistribute it and/or modify
///	it under the terms of the GNU General Public License as published by
///	the Free Software Foundation; either version 2 of the License, or
///	(at your option) any later version.
///	
///	This program is distributed in the hope that it will be useful,
///	but WITHOUT ANY WARRANTY; without even the implied warranty of
///	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
///	GNU General Public License for more details.
///	
///	You should have received a copy of the GNU General Public License
///	along with this program; if not, write to the Free Software
///	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
///	
///	--------------------------------------------------------------------------
///	
///	You can e-mail me at niallmoody@yahoo.co.uk if you want.
///	
///	--------------------------------------------------------------------------

#include "../NPBWindow.h"
#include "MaximiseButton.h"
#include "../ComponentFactory.h"

//--static member variables must be declared--
String MaximiseButton::normalImage = T("");
String MaximiseButton::overImage = T("");
String MaximiseButton::downImage = T("");
bool MaximiseButton::resize = false;

///---------------------------------------------------------------------------
MaximiseButton::MaximiseButton(ComponentFactory *factory, Component **windowComponent):
FactoryObject(factory, windowComponent)
{
	//--Set default values to allow for the user missing out on an attribute.--
	x = 380;
	y = 5;
	xRel = -1;
	yRel = -1;
	width = 30;
	height = 30;
	widthRel = -1;
	heightRel = -1;
	normalImage = convertRelativeFilePath(T("images/MaxButton_1.png"));
	overImage = convertRelativeFilePath(T("images/MaxButton_2.png"));
	downImage = convertRelativeFilePath(T("images/MaxButton_3.png"));
	resize = false;

	//Register this object with the factory.
	factory->registerObject(this, String("maximiseButton"));

	//Register all it's attributes with the factory.
	factory->registerStringAttribute(this, String("normalImage"), &MaximiseButton::setNormalImage);
	factory->registerStringAttribute(this, String("overImage"), &MaximiseButton::setOverImage);
	factory->registerStringAttribute(this, String("downImage"), &MaximiseButton::setDownImage);
	factory->registerBoolAttribute(this, String("resize"), &MaximiseButton::setResize);
}

///---------------------------------------------------------------------------
void MaximiseButton::create()
{
	NPBWindow *window;
	ImageButton *tempComp;

	normalImage = convertRelativeFilePath(normalImage);
	overImage = convertRelativeFilePath(overImage);
	downImage = convertRelativeFilePath(downImage);

	Image *image1 = ImageCache::getFromFile(File(normalImage));
	Image *image2 = ImageCache::getFromFile(File(overImage));
	Image *image3 = ImageCache::getFromFile(File(downImage));

	window = static_cast<NPBWindow *>(factory->getWindow());

	window->addAndMakeVisible(tempComp = new ImageButton(T("Maximise")));
	if(!resize)
	{
		tempComp->setImages(true, false, true,
							image1, 1.0f, Colours::transparentBlack,
							image2, 1.0f, Colours::transparentBlack,
							image3, 1.0f, Colours::transparentBlack,
							0.25f); //alpha hit test threshold
	}
	else
	{
		tempComp->setImages(false, true, false,
							image1, 1.0f, Colours::transparentBlack,
							image2, 1.0f, Colours::transparentBlack,
							image3, 1.0f, Colours::transparentBlack,
							0.5f); //alpha hit test threshold
	}

	tempComp->addActionListener(window);

	*windowComponent = tempComp;
}

///---------------------------------------------------------------------------
void MaximiseButton::setNormalImage(String image)
{
	normalImage = image;
}

///---------------------------------------------------------------------------
void MaximiseButton::setOverImage(String image)
{
	overImage = image;
}

///---------------------------------------------------------------------------
void MaximiseButton::setDownImage(String image)
{
	downImage = image;
}

///---------------------------------------------------------------------------
void MaximiseButton::setResize(bool val)
{
	resize = val;
}
